==> tuia-explore-center-api-0.0.1-20190528.070415-11-sources.jar: cn/tuia/explore/center/api/dto/rsp/UserDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: UserDto.java , v 0.1 2019-05-24 14:22 ElinZhou Exp $
 */
public class UserDto implements Serializable {
    private static final long serialVersionUID = 3442675055573256049L;

    /**
     * 昵称
     */
    private String nickName;

    /**
     * 头像
     */
    private String headImage;

    /**
     * 生日年份
     */
    private String birthdayYear;

    /**
     * 性别
     */
    private Integer gender;

    /**
     * 个性签名
     */
    private String signature;

    /**
     * 用户地区码
     */
    private String adCode;

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getBirthdayYear() {
        return birthdayYear;
    }

    public void setBirthdayYear(String birthdayYear) {
        this.birthdayYear = birthdayYear;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getSignature() {
        return signature;
    }

    public void setSignature(String signature) {
        this.signature = signature;
    }

    public String getAdCode() {
        return adCode;
    }

    public void setAdCode(String adCode) {
        this.adCode = adCode;
    }
}

==> tuia-explore-center-api-0.0.1-20190529.120309-28-sources.jar: cn/tuia/explore/center/api/dto/rsp/UserDto.java <==
package cn.tuia.explore.center.api.dto.rsp;

import java.io.Serializable;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: UserDto.java , v 0.1 2019-05-24 14:22 ElinZhou Exp $
 */
public class UserDto implements Serializable {
    private static final long serialVersionUID = 3442675055573256049L;

    /**
     * 昵称
     */
    private String nickName;

    /**
     * 头像
     */
    private String headImage;

    /**
     * 生日年份
     */
    private String birthdayYear;

    /**
     * 性别
     */
    private Integer gender;

    /**
     * 个性签名
     */
    private String signature;

    /**
     * 用户地区码
     */
    private String cityCode;

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getBirthdayYear() {
        return birthdayYear;
    }

    public void setBirthdayYear(String birthdayYear) {
        this.birthdayYear = birthdayYear;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getSignature() {
        return signature;
    }

    public void setSignature(String signature) {
        this.signature = signature;
    }

    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }
}
